# MUlti OBjective Linear Programming (MUOBLP)

This package contains core model used to define MUOB linear programs and some utility methods.

---

### Installation
See  [PyPi](https://pypi.org/project/muoblp/) project page for details

```shell
pip install muoblp
```
